@@ -13,27 +13,12 @@
 ##############################################################################
 """Location support tests
 
-$Id: tests.py 95519 2009-01-29 19:39:10Z ctheune $
+$Id: tests.py 104479 2009-09-24 11:19:54Z tlotze $
 """
 
 import unittest
-import zope.interface
 import zope.testing.doctest
 from zope.testing.doctestunit import DocTestSuite
-from zope.location.interfaces import ITraverser
-from zope.location.location import Location
-
-
-class TLocation(Location):
-    """Simple traversable location used in examples."""
-
-    zope.interface.implements(ITraverser)
-
-    def traverse(self, path, default=None, request=None):
-        o = self
-        for name in path.split(u'/'):
-           o = getattr(o, name)
-        return o
 
 
 def test_suite():
